hotspot/test/serviceability/logging/TestLogRotation.java
changeset 41723 88393c6dd24e
parent 40631 ed82623d7831
--- a/hotspot/test/serviceability/logging/TestLogRotation.java	Tue Oct 18 09:43:12 2016 +0200
+++ b/hotspot/test/serviceability/logging/TestLogRotation.java	Wed Oct 05 16:00:10 2016 +0200
@@ -41,8 +41,8 @@
     public static void main(String[] args) throws Exception {
 
         long sizeOfLog = Long.parseLong(args[0]);
-        long lines = sizeOfLog / 80;
-        // full.GC generates ad least 1-line which is not shorter then 80 chars
+        long lines = sizeOfLog / 70;
+        // full.GC generates ad least 1-line which is not shorter then 70 chars
         // for some GC 2 shorter lines are generated
         for (long i = 0; i < lines; i++) {
             System.gc();